==> pyrecipe_0.1-1.tar.gz: pyrecipe-0.1/backup.py <==
import gtk, hildon
import datetime
import pyrecipe_utils
import shutil
import sqlite3

class BackupGui:
    def __init__(self, window):        
        backup_dlg = gtk.Dialog(title='Backup', parent=None, \
                                buttons=("Cancel", gtk.RESPONSE_CLOSE))
        backup_dlg.set_size_request(280, 180) 
        self.backup_type = None
        
        date_today = datetime.date.today()	
        title = 'pyrecipe-backup-' + date_today.isoformat()
        
        import_btn = gtk.Button('Import Backup')
        import_btn.connect("clicked", self.on_import_backup, backup_dlg, title, window)
        export_btn = gtk.Button('Export Backup')
        export_btn .connect("clicked", self.on_export_backup, backup_dlg, title, window) 

        backup_dlg.vbox.pack_start(import_btn, True, True, 0)
        backup_dlg.vbox.pack_start(export_btn, True, True, 0)       

        backup_dlg.show_all()
		
        result = backup_dlg.run()
        backup_dlg.destroy()

    def on_import_backup(self, widget, dialog, title, window):
        dialog.destroy()
        self.backup_type = 'import'
        namefile = pyrecipe_utils.show_open_dialog(window, "Import Backup")
            
        if namefile == None:
            self.backup_type = None
            return
            
        db_old = sqlite3.connect(namefile)
        saved_reclist = pyrecipe_utils.get_recipe_list(db_old)
        #print 'saved_list: ', saved_reclist
            
        db_current = sqlite3.connect('database')
        current_reclist = pyrecipe_utils.get_recipe_list(db_current)
        #print 'current list: ', current_reclist

        same_recipe = []
        self.backup_titles = []
        for i in range(len(saved_reclist)):
            for j in range(len(current_reclist)):
                if saved_reclist[i][1] == current_reclist[j][1]:
                    #print 'same recipe: ', saved_reclist[i][1]
                    same_recipe.append(saved_reclist[i][1])                        
                else:
                    #print 'different recipe: ', saved_reclist[i][1]
                    pass

        for k in range(len(saved_reclist)):
            if saved_reclist[k][1] in same_recipe:
                pass
            else:
                self.backup_titles.append(saved_reclist[k][1])

        self.recipe_ids = []           
        for n in range(len(self.backup_titles)):
            lista = []            
            ##get the new recipes from the database
            for row in db_old.execute('select * from recipes where title="%s"' % self.backup_titles[n]):
                lista.append(row)
                
            ##add the new recipes to the database           
            sqlite_cursor = db_current.cursor()

            sqlite_cursor.execute('INSERT INTO recipes VALUES (null, ?, ?, \
                            ?, ?, ?, ?, ?, ?, ?)', (lista[0][1], lista[0][2], \
                            lista[0][3], lista[0][4], lista[0][5], \
                            lista[0][6], lista[0][7], lista[0][8], \
                            lista[0][9]))
                
            db_current.commit()
           
            new_recipe_id = sqlite_cursor.lastrowid
            self.recipe_ids.append(new_recipe_id)
            sqlite_cursor.close()

    def on_export_backup(self, widget, dialog, title, window):
        dialog.destroy()
        self.backup_type = 'export'        
        namefile = pyrecipe_utils.show_save_dialog(window, title, 'backup', 'db')

        if namefile == None:
            self.backup_type = None        
            return
            
        shutil.copyfile('database', namefile)

==> pyrecipe_0.1-2.tar.gz: pyrecipe-0.1/backup.py <==
import gtk, hildon
import datetime
import pyrecipe_utils
import shutil
import sqlite3

class BackupGui:
    def __init__(self, window):        
        backup_dlg = gtk.Dialog(title='Backup', parent=None, \
                                buttons=("Cancel", gtk.RESPONSE_CLOSE))
        backup_dlg.set_size_request(280, 180) 
        self.backup_type = None
        
        date_today = datetime.date.today()	
        title = 'pyrecipe-backup-' + date_today.isoformat()
        
        import_btn = gtk.Button('Import Backup')
        import_btn.connect("clicked", self.on_import_backup, backup_dlg, title, window)
        export_btn = gtk.Button('Export Backup')
        export_btn .connect("clicked", self.on_export_backup, backup_dlg, title, window) 

        backup_dlg.vbox.pack_start(import_btn, True, True, 0)
        backup_dlg.vbox.pack_start(export_btn, True, True, 0)       

        backup_dlg.show_all()
		
        result = backup_dlg.run()
        backup_dlg.destroy()

    def on_import_backup(self, widget, dialog, title, window):
        dialog.destroy()
        self.backup_type = 'import'
        namefile = pyrecipe_utils.show_open_dialog(window, "Import Backup")
            
        if namefile == None:
            self.backup_type = None
            return
            
        db_old = sqlite3.connect(namefile)
        saved_reclist = pyrecipe_utils.get_recipe_list(db_old)
        #print 'saved_list: ', saved_reclist
            
        db_current = sqlite3.connect('/home/user/.pyrecipe/database')
        current_reclist = pyrecipe_utils.get_recipe_list(db_current)
        #print 'current list: ', current_reclist

        same_recipe = []
        self.backup_titles = []
        for i in range(len(saved_reclist)):
            for j in range(len(current_reclist)):
                if saved_reclist[i][1] == current_reclist[j][1]:
                    #print 'same recipe: ', saved_reclist[i][1]
                    same_recipe.append(saved_reclist[i][1])                        
                else:
                    #print 'different recipe: ', saved_reclist[i][1]
                    pass

        for k in range(len(saved_reclist)):
            if saved_reclist[k][1] in same_recipe:
                pass
            else:
                self.backup_titles.append(saved_reclist[k][1])

        self.recipe_ids = []           
        for n in range(len(self.backup_titles)):
            lista = []            
            ##get the new recipes from the database
            for row in db_old.execute('select * from recipes where title="%s"' % self.backup_titles[n]):
                lista.append(row)
                
            ##add the new recipes to the database           
            sqlite_cursor = db_current.cursor()

            sqlite_cursor.execute('INSERT INTO recipes VALUES (null, ?, ?, \
                            ?, ?, ?, ?, ?, ?, ?)', (lista[0][1], lista[0][2], \
                            lista[0][3], lista[0][4], lista[0][5], \
                            lista[0][6], lista[0][7], lista[0][8], \
                            lista[0][9]))
                
            db_current.commit()
           
            new_recipe_id = sqlite_cursor.lastrowid
            self.recipe_ids.append(new_recipe_id)
            sqlite_cursor.close()

    def on_export_backup(self, widget, dialog, title, window):
        dialog.destroy()
        self.backup_type = 'export'        
        namefile = pyrecipe_utils.show_save_dialog(window, title, 'backup', 'db')

        if namefile == None:
            self.backup_type = None        
            return
            
        shutil.copyfile('database', namefile)
